export declare enum SshKeyType {
    RSA = "RSA",
    ED25519 = "ED25519",
}
export interface ISshKeyPath {
    keyPath?: string;
}
export interface ISshKey extends ISshKeyPath, IKeyPair {
    id?: string;
    name: string;
    keyType: string;
    createdAt: string;
}
export interface ISshKeyInputAbstract {
    id?: string;
    name: string;
    keyType: SshKeyType;
    comment?: string;
}
export declare type ISshKeyInput = ISshKeyInputAbstract & IKeyPair;
export declare type ISshKeyDbInput = ISshKeyInputAbstract & ISshKeyPath & {
    keyPath: string;
};
export interface IKeyPair {
    key: string;
    pubKey: string;
}
export interface IGetSshKeyInput {
    name: string;
}
export interface IDeleteSshKeyInput {
    name: string;
}
export interface IUpdateSshKeyPatchInputAbstract {
    name: string;
    keyType: SshKeyType;
}
export declare type IUpdateSshKeyPatchInput = IUpdateSshKeyPatchInputAbstract & IKeyPair;
export interface IUpdateSshKeyDbInput {
    id?: string;
    name: string;
    patch: IUpdateSshKeyPatchInputAbstract & ISshKeyPath;
}
export interface IUpdateSshKeyInput {
    id?: string;
    name: string;
    patch: IUpdateSshKeyPatchInput;
}
export interface IKeyParams {
    location: string;
    comment?: string;
    password?: string;
    read?: boolean;
    size?: number;
    destroy?: boolean;
}
export declare type IKeyGenPayload = {
    ok: boolean;
    keypair?: IKeyPair;
    error?: Error;
};
export interface ISshKeyService {
    generateKeys(name: string, comment?: string): Promise<ISshKey>;
    addSshKey(input: ISshKeyInput): Promise<ISshKey>;
    updateSshKey(input: IUpdateSshKeyInput): Promise<ISshKey>;
    deleteSshKey(input: IDeleteSshKeyInput): Promise<boolean>;
    getSshKey(input: IGetSshKeyInput): Promise<ISshKey>;
}
